@@ -14,7 +14,7 @@ our %EXPORT_TAGS = ( 'all' => [ qw( add_image query_id loaddb savedb cleardb
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw( );
 
-our $VERSION = '0.04_01';
+our $VERSION = '0.04_02';
 
 require XSLoader;
 XSLoader::load('Image::Seek', $VERSION);
@@ -26,9 +26,28 @@ sub add_image {
     if (UNIVERSAL::isa($image, "Imager"))        { goto &add_image_imager }
     if (UNIVERSAL::isa($image, "Image::Imlib2")) { goto &add_image_imlib2 }
     if (UNIVERSAL::isa($image, "GD::Image"))     { goto &add_image_gd }
+    if (UNIVERSAL::isa($image, "Image::Magick")) { goto &add_image_magick }
     croak "Don't know what sort of image $image is";
 }
 
+sub add_image_magick {
+    my ($img, $id) = @_;
+    my ($reds, $blues, $greens);
+
+    #$image->Get('width', 'height');
+
+    my $thumb = $img->Clone();
+    $thumb->Scale('128x128!');
+
+    for my $y (0..127) {
+        for my $x (0..127) {
+            my ($r, $g, $b) = $thumb->GetPixel('x' => $x, 'y' => $y);
+            $reds .= chr($r); $blues .= chr($b); $greens .= chr($g);
+        }
+    }
+    addImage($id, $reds, $greens, $blues);
+}
+
 sub add_image_gd {
     my ($img, $id) = @_;
     my ($reds, $blues, $greens);
@@ -188,6 +207,42 @@ Notice that the scores go the opposite way to what you might imagine:
 lower is better. The results come out sorted, and the first result is
 the thing you queried for.
 
+=head2 addImage($id, $reds, $greens, $blues)
+
+Internally used.
+
+=head2 add_image_magick($image, $id)
+
+Internally used.
+
+=head2 add_image_gd($image, $id)
+
+Internally used.
+
+=head2 add_image_imager($image, $id)
+
+Internally used.
+
+=head2 add_image_imlib2($image, $id)
+
+Internally used.
+
+=head2 constant
+
+Internally used.
+
+=head2 queryImgID
+
+Internally used.
+
+=head2 removeID
+
+Internally used.
+
+=head2 results
+
+Internally used.
+
 =head1 SEE ALSO
 
 http://www.imgseek.net/
